==> vue-loading-2.8.0.tgz: package/lib/mobile-first.js <==
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import { defineComponent, $prefix, $props, setup as _setup } from "@xmweb-ui/vue-common";
import { renderless, api } from "@xmweb-ui/vue-renderless/loading/vue";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "loading-default": "m-0 top-0 right-0 left-0 bottom-0 block transition bg-color-bg-1 duration-[2000ms]",
  "loading-fullscreen": "fixed opacity-80",
  "loading-unfullscreen": "absolute",
  "loading-content": "absolute -translate-y-2/4  w-full  top-1/2 text-center  flex justify-center items-center",
  "loading-size-mini": "flex-row",
  "loading-size-unmini": "flex-col",
  "loading-unspinner": "animate-[spin_1.5s_linear_infinite] fill-current",
  "loading-unspinner-size-default": "h-10 w-10 stroke-2",
  "loading-unspinner-size-large": "h-24 w-24 stroke-2",
  "loading-unspinner-size-medium": "h-10 w-10 stroke-2",
  "loading-unspinner-size-small": "h-6 w-6 stroke-1",
  "loading-unspinner-size-mini": "h-3.5 w-3.5 stroke-1",
  "loading-unspinner-svg-circle": "stroke-color-brand xm-loading-path",
  "loading-spinner": "text-sm fill-color-brand leading-none animate-[spin_2s_linear_infinite]",
  "loading-spinner-text": "xm-tailwind-text block text-color-brand  text-xs leading-6",
  "loading-spinner-size-mini": "my-0 ml-2",
  "loading-spinner-size-unmini": "mb-1 mt-2.5"
};
var __vue2_script = defineComponent({
  inheritAttrs: false,
  name: $prefix + "Loading",
  props: _extends({}, $props, {
    _constants: Object
  }),
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "xm-loading-fade"
    },
    on: {
      "after-leave": _vm.handleAfterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    class: _vm.m(_vm.state.customClass, _vm.gcls("loading-default"), _vm.gcls({
      "loading-fullscreen": _vm.state.fullscreen
    }), _vm.gcls({
      "loading-unfullscreen": !_vm.state.fullscreen
    })),
    style: "background-color:" + _vm.state.background
  }, [_c("div", {
    class: _vm.m(_vm.gcls("loading-content"), _vm.gcls({
      "loading-size-mini": _vm.state.size === "mini"
    }), _vm.gcls({
      "loading-size-unmini": _vm.state.size !== "mini"
    }))
  }, [!_vm.state.spinner ? _c("svg", {
    class: _vm.m(_vm.gcls("loading-unspinner"), _vm.gcls({
      "loading-unspinner-size-default": !_vm.state.size || !["large", "medium", "small", "mini"].includes(_vm.state.size)
    }), _vm.gcls({
      "loading-unspinner-size-large": _vm.state.size === "large"
    }), _vm.gcls({
      "loading-unspinner-size-medium": _vm.state.size === "medium"
    }), _vm.gcls({
      "loading-unspinner-size-small": _vm.state.size === "small"
    }), _vm.gcls({
      "loading-unspinner-size-mini": _vm.state.size === "mini"
    })),
    attrs: {
      "viewBox": "25 25 50 50"
    }
  }, [_c("circle", {
    class: _vm.m(_vm.gcls("loading-unspinner-svg-circle")),
    attrs: {
      "cx": "50",
      "cy": "50",
      "r": "24",
      "fill": "none"
    }
  })]) : _c(_vm.state.spinner, {
    tag: "component",
    class: _vm.m(_vm.gcls("loading-spinner"))
  }), _vm.state.text ? _c("span", {
    class: _vm.m(_vm.gcls("loading-spinner-text"), _vm.gcls({
      "loading-spinner-size-mini": _vm.state.size === "mini"
    }), _vm.gcls({
      "loading-spinner-size-unmini": _vm.state.size !== "mini"
    }))
  }, [_vm._v(_vm._s(_vm.state.text))]) : _vm._e()], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-loading-2.8.2.tgz: package/lib/mobile-first.js <==
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import { defineComponent, $prefix, $props, setup as _setup } from "@opentiny/vue-common";
import { renderless, api } from "@opentiny/vue-renderless/loading/vue";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "loading-default": "m-0 top-0 right-0 left-0 bottom-0 block transition bg-color-bg-1 duration-[2000ms]",
  "loading-fullscreen": "fixed opacity-80",
  "loading-unfullscreen": "absolute",
  "loading-content": "absolute -translate-y-2/4  w-full  top-1/2 text-center  flex justify-center items-center",
  "loading-size-mini": "flex-row",
  "loading-size-unmini": "flex-col",
  "loading-unspinner": "animate-[spin_1.5s_linear_infinite] fill-current",
  "loading-unspinner-size-default": "h-10 w-10 stroke-2",
  "loading-unspinner-size-large": "h-24 w-24 stroke-2",
  "loading-unspinner-size-medium": "h-10 w-10 stroke-2",
  "loading-unspinner-size-small": "h-6 w-6 stroke-1",
  "loading-unspinner-size-mini": "h-3.5 w-3.5 stroke-1",
  "loading-unspinner-svg-circle": "stroke-color-brand tiny-loading-path",
  "loading-spinner": "text-sm fill-color-brand leading-none animate-[spin_2s_linear_infinite]",
  "loading-spinner-text": "tiny-tailwind-text block text-color-brand  text-xs leading-6",
  "loading-spinner-size-mini": "my-0 ml-2",
  "loading-spinner-size-unmini": "mb-1 mt-2.5"
};
var __vue2_script = defineComponent({
  inheritAttrs: false,
  name: $prefix + "Loading",
  props: _extends({}, $props, {
    _constants: Object
  }),
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-loading-fade"
    },
    on: {
      "after-leave": _vm.handleAfterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    class: _vm.m(_vm.state.customClass, _vm.gcls("loading-default"), _vm.gcls({
      "loading-fullscreen": _vm.state.fullscreen
    }), _vm.gcls({
      "loading-unfullscreen": !_vm.state.fullscreen
    })),
    style: "background-color:" + _vm.state.background
  }, [_c("div", {
    class: _vm.m(_vm.gcls("loading-content"), _vm.gcls({
      "loading-size-mini": _vm.state.size === "mini"
    }), _vm.gcls({
      "loading-size-unmini": _vm.state.size !== "mini"
    }))
  }, [!_vm.state.spinner ? _c("svg", {
    class: _vm.m(_vm.gcls("loading-unspinner"), _vm.gcls({
      "loading-unspinner-size-default": !_vm.state.size || !["large", "medium", "small", "mini"].includes(_vm.state.size)
    }), _vm.gcls({
      "loading-unspinner-size-large": _vm.state.size === "large"
    }), _vm.gcls({
      "loading-unspinner-size-medium": _vm.state.size === "medium"
    }), _vm.gcls({
      "loading-unspinner-size-small": _vm.state.size === "small"
    }), _vm.gcls({
      "loading-unspinner-size-mini": _vm.state.size === "mini"
    })),
    attrs: {
      "viewBox": "25 25 50 50"
    }
  }, [_c("circle", {
    class: _vm.m(_vm.gcls("loading-unspinner-svg-circle")),
    attrs: {
      "cx": "50",
      "cy": "50",
      "r": "24",
      "fill": "none"
    }
  })]) : _c(_vm.state.spinner, {
    tag: "component",
    class: _vm.m(_vm.gcls("loading-spinner"))
  }), _vm.state.text ? _c("span", {
    class: _vm.m(_vm.gcls("loading-spinner-text"), _vm.gcls({
      "loading-spinner-size-mini": _vm.state.size === "mini"
    }), _vm.gcls({
      "loading-spinner-size-unmini": _vm.state.size !== "mini"
    }))
  }, [_vm._v(_vm._s(_vm.state.text))]) : _vm._e()], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};
